Struct stack_queue::assignment::TaskAssignment
source · Expand description
An assignment of a task range to be processed
Implementations
sourceimpl<'a, T, const N: usize> TaskAssignment<'a, T, N>where
T: TaskQueue,
impl<'a, T, const N: usize> TaskAssignment<'a, T, N>where
T: TaskQueue,
sourcepub fn resolve_with_iter<I>(self, iter: I) -> CompletionReceipt<T>where
I: IntoIterator<Item = T::Value>,
pub fn resolve_with_iter<I>(self, iter: I) -> CompletionReceipt<T>where
I: IntoIterator<Item = T::Value>,
Resolve task assignment with an iterator where indexes align with tasks
sourcepub fn map<F>(self, op: F) -> CompletionReceipt<T>where
F: Fn(T::Task) -> T::Value + Sync,
pub fn map<F>(self, op: F) -> CompletionReceipt<T>where
F: Fn(T::Task) -> T::Value + Sync,
Resolve task assignment by mapping each task into it’s respective value
sourcepub async fn with_blocking<F>(self, f: F) -> CompletionReceipt<T>where
F: for<'b> FnOnce(TaskAssignment<'b, T, N>) -> CompletionReceipt<T> + Send + 'static,
pub async fn with_blocking<F>(self, f: F) -> CompletionReceipt<T>where
F: for<'b> FnOnce(TaskAssignment<'b, T, N>) -> CompletionReceipt<T> + Send + 'static,
Resolve task assignment within a thread where blocking is acceptable. If the runtime would otherwise shutdown, instead it will suspend for the lifetime of this thread as to protect the underlying thread local data from being destroyed